=======
Signals
=======

.. currentmodule:: pulsarbat

.. autosummary::
   :toctree: generated/
   :template: signal_class.rst

    Signal
    RadioSignal
    IntensitySignal
    FullStokesSignal
    BasebandSignal
    DualPolarizationSignal
